# Re-Visit

Re-Visit is a tool to help you manage your bookmarks with custom webview. It 's inspired by [shiori](https://github.com/shiori/shiori), you can say it's a clone of shiori but build in python.


## Features

- Basic bookmarks management i.e. add, edit, delete and search.
- Import and export bookmarks from and to Netscape Bookmark file.
- Simple and clean command line interface.
- Simple and pretty web interface for those who don't want to use a command line app.

## Documentation

You can find the documentation [here](https://github.com/myboo/re-visit/blob/main/docs/README.md).